@@ -1,6 +1,6 @@
 package Dancer2::Plugin::Chain::Router;
 
-$Dancer2::Plugin::Chain::Router::VERSION   = '0.07';
+$Dancer2::Plugin::Chain::Router::VERSION   = '0.08';
 $Dancer2::Plugin::Chain::Router::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Dancer2::Plugin::Chain::Router - Helper package for Dancer2::Plugin::Chain.
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
@@ -200,4 +200,4 @@ OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
 
-1; # End of Dancer2-Plugin-Chain::Router
+1; # End of Dancer2::Plugin::Chain::Router
